==> aws_cdk.aws_lambda_nodejs-1.136.0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_lambda_nodejs_LogLevel(p) {
}
function _aws_cdk_aws_lambda_nodejs_SourceMapMode(p) {
}
function _aws_cdk_aws_lambda_nodejs_Charset(p) {
}
function _aws_cdk_aws_lambda_nodejs_ICommandHooks(p) {
}
function _aws_cdk_aws_lambda_nodejs_NodejsFunctionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bundling))
        _aws_cdk_aws_lambda_nodejs_BundlingOptions(p.bundling);
    if ("architectures" in p)
        print("@aws-cdk/aws-lambda.FunctionOptions#architectures", "use `architecture`");
    if (!visitedObjects.has(p.architectures))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_Architecture(p.architectures);
    if (!visitedObjects.has(p.events))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_IEventSource(p.events);
    if (!visitedObjects.has(p.initialPolicy))
        require("@aws-cdk/aws-iam/.warnings.jsii.js")._aws_cdk_aws_iam_PolicyStatement(p.initialPolicy);
    if (!visitedObjects.has(p.layers))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_ILayerVersion(p.layers);
    if ("securityGroup" in p)
        print("@aws-cdk/aws-lambda.FunctionOptions#securityGroup", "- This property is deprecated, use securityGroups instead");
    if (!visitedObjects.has(p.securityGroups))
        require("@aws-cdk/aws-ec2/.warnings.jsii.js")._aws_cdk_aws_ec2_ISecurityGroup(p.securityGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_lambda_nodejs_NodejsFunction(p) {
}
function _aws_cdk_aws_lambda_nodejs_BundlingOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.charset))
        _aws_cdk_aws_lambda_nodejs_Charset(p.charset);
    if (!visitedObjects.has(p.commandHooks))
        _aws_cdk_aws_lambda_nodejs_ICommandHooks(p.commandHooks);
    if (!visitedObjects.has(p.logLevel))
        _aws_cdk_aws_lambda_nodejs_LogLevel(p.logLevel);
    if (!visitedObjects.has(p.sourceMapMode))
        _aws_cdk_aws_lambda_nodejs_SourceMapMode(p.sourceMapMode);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_lambda_nodejs_LogLevel, _aws_cdk_aws_lambda_nodejs_SourceMapMode, _aws_cdk_aws_lambda_nodejs_Charset, _aws_cdk_aws_lambda_nodejs_ICommandHooks, _aws_cdk_aws_lambda_nodejs_NodejsFunctionProps, _aws_cdk_aws_lambda_nodejs_NodejsFunction, _aws_cdk_aws_lambda_nodejs_BundlingOptions };
module.exports.DeprecationError = DeprecationError;

==> aws_cdk.aws_lambda_nodejs-1.138.1-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_lambda_nodejs_LogLevel(p) {
}
function _aws_cdk_aws_lambda_nodejs_SourceMapMode(p) {
}
function _aws_cdk_aws_lambda_nodejs_Charset(p) {
}
function _aws_cdk_aws_lambda_nodejs_ICommandHooks(p) {
}
function _aws_cdk_aws_lambda_nodejs_NodejsFunction(p) {
}
function _aws_cdk_aws_lambda_nodejs_NodejsFunctionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bundling))
        _aws_cdk_aws_lambda_nodejs_BundlingOptions(p.bundling);
    if ("architectures" in p)
        print("@aws-cdk/aws-lambda.FunctionOptions#architectures", "use `architecture`");
    if (!visitedObjects.has(p.architectures))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_Architecture(p.architectures);
    if (!visitedObjects.has(p.events))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_IEventSource(p.events);
    if (!visitedObjects.has(p.initialPolicy))
        require("@aws-cdk/aws-iam/.warnings.jsii.js")._aws_cdk_aws_iam_PolicyStatement(p.initialPolicy);
    if (!visitedObjects.has(p.layers))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_ILayerVersion(p.layers);
    if ("securityGroup" in p)
        print("@aws-cdk/aws-lambda.FunctionOptions#securityGroup", "- This property is deprecated, use securityGroups instead");
    if (!visitedObjects.has(p.securityGroups))
        require("@aws-cdk/aws-ec2/.warnings.jsii.js")._aws_cdk_aws_ec2_ISecurityGroup(p.securityGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_lambda_nodejs_BundlingOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.charset))
        _aws_cdk_aws_lambda_nodejs_Charset(p.charset);
    if (!visitedObjects.has(p.commandHooks))
        _aws_cdk_aws_lambda_nodejs_ICommandHooks(p.commandHooks);
    if (!visitedObjects.has(p.logLevel))
        _aws_cdk_aws_lambda_nodejs_LogLevel(p.logLevel);
    if (!visitedObjects.has(p.sourceMapMode))
        _aws_cdk_aws_lambda_nodejs_SourceMapMode(p.sourceMapMode);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_lambda_nodejs_LogLevel, _aws_cdk_aws_lambda_nodejs_SourceMapMode, _aws_cdk_aws_lambda_nodejs_Charset, _aws_cdk_aws_lambda_nodejs_ICommandHooks, _aws_cdk_aws_lambda_nodejs_NodejsFunction, _aws_cdk_aws_lambda_nodejs_NodejsFunctionProps, _aws_cdk_aws_lambda_nodejs_BundlingOptions };
module.exports.DeprecationError = DeprecationError;
